@@ -10,6 +10,7 @@ from ..services.conversation import ConversationService
 from ..services.datasource import DatasourceService
 from ..services.llm import LLMService
 from ..services.integration import IntegrationService
+from ..services.mermaid import MermaidService
 from ..services.task import TaskService
 from ..services.user import UserService
 from ..services.workflow import WorkflowService
@@ -80,6 +81,9 @@ class CodeMieClient:
             self._api_domain, self._token, verify_ssl=verify_ssl
         )
         self.llms = LLMService(self._api_domain, self._token, verify_ssl=verify_ssl)
+        self.mermaid = MermaidService(
+            self._api_domain, self._token, verify_ssl=verify_ssl
+        )
         self.integrations = IntegrationService(
             self._api_domain, self._token, verify_ssl=verify_ssl
         )
@@ -150,6 +154,9 @@ class CodeMieClient:
         self.llms = LLMService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.mermaid = MermaidService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
         self.integrations = IntegrationService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
